@@ -259,7 +259,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
     <message>
         <location filename="../mainwindow.ui" line="121"/>
         <source>&amp;Icon Size</source>
-        <translation>&amp;Размер значка</translation>
+        <translation>&amp;Размер значков</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="147"/>
@@ -314,7 +314,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
     <message>
         <location filename="../mainwindow.ui" line="231"/>
         <source>&amp;Test</source>
-        <translation>Про&amp;тестировать</translation>
+        <translation>Пров&amp;ерить</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="234"/>
